@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
 import os.path
@@ -94,7 +93,10 @@ class Prospector(object):
                     raise
                 else:
                     loc = Location(self.config.workdir, None, None, None, None)
-                    msg = "Tool %s failed to run (exception was raised)" % (toolname,)
+                    msg = (
+                        "Tool %s failed to run (exception was raised, re-run prospector with -X to see the stacktrace)"
+                        % (toolname,)
+                    )
                     message = Message(
                         toolname,
                         "failure",
